==> pylucene-2.9.1-1-src.tar.gz: pylucene-2.9.1-1/lucene-java-2.9.1/contrib/xml-query-parser/src/java/org/apache/lucene/xmlparser/builders/SpanQueryBuilderFactory.java <==
package org.apache.lucene.xmlparser.builders;

import java.util.HashMap;

import org.apache.lucene.search.Query;
import org.apache.lucene.search.spans.SpanQuery;
import org.apache.lucene.xmlparser.ParserException;
import org.w3c.dom.Element;
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * 
 */
public class SpanQueryBuilderFactory implements SpanQueryBuilder {

	HashMap builders=new HashMap();
	
	public Query getQuery(Element e) throws ParserException {
		return getSpanQuery(e);
	}
	public void addBuilder(String nodeName,SpanQueryBuilder builder)
	{
		builders.put(nodeName,builder);
	}
	public SpanQuery getSpanQuery(Element e) throws ParserException
	{
		SpanQueryBuilder builder=(SpanQueryBuilder) builders.get(e.getNodeName());
		if(builder==null)
		{
			throw new ParserException("No SpanQueryObjectBuilder defined for node "+e.getNodeName()); 
		}
		return builder.getSpanQuery(e); 
	}

}

==> pylucene-3.0.3-1-src.tar.gz: pylucene-3.0.3-1/lucene-java-3.0.3/contrib/xml-query-parser/src/java/org/apache/lucene/xmlparser/builders/SpanQueryBuilderFactory.java <==
package org.apache.lucene.xmlparser.builders;

import java.util.HashMap;

import org.apache.lucene.search.Query;
import org.apache.lucene.search.spans.SpanQuery;
import org.apache.lucene.xmlparser.ParserException;
import org.w3c.dom.Element;
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * 
 */
public class SpanQueryBuilderFactory implements SpanQueryBuilder {

	HashMap<String,SpanQueryBuilder> builders=new HashMap<String,SpanQueryBuilder>();
	
	public Query getQuery(Element e) throws ParserException {
		return getSpanQuery(e);
	}
	public void addBuilder(String nodeName,SpanQueryBuilder builder)
	{
		builders.put(nodeName,builder);
	}
	public SpanQuery getSpanQuery(Element e) throws ParserException
	{
		SpanQueryBuilder builder= builders.get(e.getNodeName());
		if(builder==null)
		{
			throw new ParserException("No SpanQueryObjectBuilder defined for node "+e.getNodeName()); 
		}
		return builder.getSpanQuery(e); 
	}

}
